@@ -318,6 +318,9 @@ test_that("snapshot() accepts relative library paths", {
 
 test_that("snapshot(update = TRUE) preserves old records", {
 
+  skip_on_cran()
+  skip_if_no_github_auth()
+
   renv_tests_scope("breakfast")
   init()
 
@@ -615,37 +618,37 @@ test_that("standard remotes drop RemoteSha if it's a version", {
 })
 
 test_that("a package's hash can be re-generated from lockfile", {
-  
+
   project <- renv_tests_scope("breakfast")
   init()
-  
+
   lockfile <- snapshot(lockfile = NULL)
   records <- renv_lockfile_records(lockfile)
-  
+
   enumerate(records, function(package, record) {
     path <- system.file("DESCRIPTION", package = package)
     actual <- renv_hash_description(path)
     expected <- renv_hash_record(record)
     expect_equal(actual, expected)
   })
-  
+
 })
 
 test_that("lockfiles are stable (v1)", {
-  
+
   renv_scope_options(renv.lockfile.version = 1L)
-  
+
   project <- renv_tests_scope("breakfast")
   init()
-  
+
   expect_snapshot(. <- writeLines(readLines("renv.lock")))
-  
+
 })
 
 test_that("lockfiles are stable (v2)", {
-  
+
   renv_scope_options(renv.lockfile.version = 2L)
-  
+
   project <- renv_tests_scope("breakfast")
   init()
 
@@ -664,3 +667,15 @@ test_that("empty .ipynb files are handled gracefully", {
   snapshot()
 
 })
+
+test_that("invalid lockfiles don't prevent calls to snapshot", {
+
+  skip_on_cran()
+  project <- renv_tests_scope("bread")
+  init()
+
+  writeLines("whoops!", con = "renv.lock")
+  suppressWarnings(snapshot())
+  expect_true(TRUE)
+
+})
